@@ -7,6 +7,7 @@ use std::borrow::Cow;
 
 #[derive(Clone, Debug, PartialEq)]
 pub enum Pattern {
+    Map(Vec<(String, Pattern)>),
     List(Vec<Pattern>),
     Val(TData),
     Filter(Expr),
@@ -39,6 +40,22 @@ impl Pattern {
                 }
                 _ => false,
             },
+            Pattern::Map(mpat) => match d {
+                TData::Map(mp) => {
+                    for (k, p) in mpat {
+                        match mp.get(k) {
+                            Some(v) => {
+                                if !p.match_data(v, scope, tm, fm) {
+                                    return false;
+                                }
+                            }
+                            None => return false,
+                        }
+                    }
+                    true
+                }
+                _ => false,
+            },
             Pattern::Capture(id, Some(test)) => {
                 if test.match_data(d, scope, tm, fm) {
                     scope.set(id, d.clone());
